@@ -11,12 +11,12 @@ readsf~ and writesf~ are defined which confine disk operations to a separate
 thread so that they can be used in real time.  The readsf~ and writesf~
 objects use Posix-like threads.  */
 
-#ifndef MSW
+#ifndef _WIN32
 #include <unistd.h>
 #include <fcntl.h>
 #endif
 #include <pthread.h>
-#ifdef MSW
+#ifdef _WIN32
 #include <io.h>
 #endif
 #include <stdio.h>
@@ -32,7 +32,7 @@ objects use Posix-like threads.  */
 # define lseek lseek64
 #define off_t __off64_t
 #endif
-#ifdef MSW
+#ifdef _WIN32
 #define off_t long
 #endif
 
@@ -154,7 +154,7 @@ typedef struct _aiff
 
 #define OBUFSIZE MAXPDSTRING  /* assume MAXPDSTRING is bigger than headers */
 
-#ifdef MSW
+#ifdef _WIN32
 #include <fcntl.h>
 #define BINCREATE _O_WRONLY | _O_CREAT | _O_TRUNC | _O_BINARY
 #else
@@ -286,7 +286,8 @@ int open_soundfile_via_fd(int fd, int headersize,
             {
                 long chunksize = swap4(((t_wavechunk *)buf)->wc_size,
                     swap), seekto = headersize + chunksize + 8, seekout;
-                
+                if (seekto & 1)     /* pad up to even number of bytes */
+                    seekto++;                
                 if (!strncmp(((t_wavechunk *)buf)->wc_id, "fmt ", 4))
                 {
                     long commblockonset = headersize + 8;
@@ -338,6 +339,8 @@ int open_soundfile_via_fd(int fd, int headersize,
             {
                 long chunksize = swap4(((t_datachunk *)buf)->dc_size,
                     swap), seekto = headersize + chunksize + 8, seekout;
+                if (seekto & 1)     /* pad up to even number of bytes */
+                    seekto++;
                 /* post("chunk %c %c %c %c seek %d",
                     ((t_datachunk *)buf)->dc_id[0],
                     ((t_datachunk *)buf)->dc_id[1],
@@ -368,8 +371,8 @@ int open_soundfile_via_fd(int fd, int headersize,
                         goto badheader;
                 headersize = seekto;
             }
-            bytelimit = swap4(((t_datachunk *)buf)->dc_size, swap);
-            headersize += 8;
+            bytelimit = swap4(((t_datachunk *)buf)->dc_size, swap) - 8;
+            headersize += sizeof(t_datachunk);
         }
     }
         /* seek past header and any sample frames to skip */
@@ -784,9 +787,13 @@ static int create_soundfile(t_canvas *canvas, const char *filename,
         memcpy(&aiffhdr->a_nframeshi, &longtmp, 4);
         aiffhdr->a_bitspersamp = swap2(8 * bytespersamp, swap);
         memcpy(aiffhdr->a_samprate, dogdoo, sizeof(dogdoo));
-        longtmp = swap4(datasize, swap);
-        memcpy(aiffhdr->a_samprate + sizeof(dogdoo), &longtmp, 4);
-        memset(aiffhdr->a_samprate + sizeof(dogdoo) + 4, 0, 8);
+        longtmp = swap4(datasize + 8, swap);
+        memcpy(headerbuf +
+            ((aiffhdr->a_samprate + sizeof(dogdoo))-(unsigned char *)aiffhdr),
+                &longtmp, 4);
+        memset(headerbuf +
+            ((aiffhdr->a_samprate + sizeof(dogdoo))-(unsigned char *)aiffhdr)
+                + 4, 0, 8);
         headersize = AIFFPLUS;
     }
     else    /* WAVE format */
@@ -1327,7 +1334,7 @@ static void soundfiler_read(t_soundfiler *x, t_symbol *s,
     goto done;
 usage:
     pd_error(x, "usage: read [flags] filename tablename...");
-    post("flags: -skip <n> -nframes <n> -resize -maxsize <n> ...");
+    post("flags: -skip <n> -resize -maxsize <n> ...");
     post("-raw <headerbytes> <channels> <bytespersamp> <endian (b, l, or n)>.");
 done:
     if (fd >= 0)
