@@ -16,7 +16,7 @@
 #include "g_all_guis.h"
 #include <math.h>
 
-#ifdef MSW
+#ifdef _WIN32
 #include <io.h>
 #else
 #include <unistd.h>
