@@ -991,7 +991,7 @@ void canvas_vis(t_canvas *x, t_floatarg f)
             if (glist_isvisible(gl2))
                 gobj_vis(&x->gl_gobj, gl2, 0);
             x->gl_havewindow = 0;
-            if (glist_isvisible(gl2))
+            if (glist_isvisible(gl2) && !gl2->gl_isdeleting)
                 gobj_vis(&x->gl_gobj, gl2, 1);
         }
         else x->gl_havewindow = 0;
@@ -1700,14 +1700,22 @@ void canvas_key(t_canvas *x, t_symbol *s, int ac, t_atom *av)
         keynamesym = gensym("#keyname");
     }
 #ifdef __APPLE__
-        if (keynum == 30)
+        if (keynum == 30 || keynum == 63232)
             keynum = 0, gotkeysym = gensym("Up");
-        else if (keynum == 31)
+        else if (keynum == 31 || keynum == 63233)
             keynum = 0, gotkeysym = gensym("Down");
-        else if (keynum == 28)
+        else if (keynum == 28 || keynum == 63234)
             keynum = 0, gotkeysym = gensym("Left");
-        else if (keynum == 29)
+        else if (keynum == 29 || keynum == 63235)
             keynum = 0, gotkeysym = gensym("Right");
+        else if (keynum == 63273)
+            keynum = 0, gotkeysym = gensym("Home");
+        else if (keynum == 63275)
+            keynum = 0, gotkeysym = gensym("End");
+        else if (keynum == 63276)
+            keynum = 0, gotkeysym = gensym("Prior");
+        else if (keynum == 63277)
+            keynum = 0, gotkeysym = gensym("Next");
 #endif
     if (keynumsym->s_thing && down)
         pd_float(keynumsym->s_thing, (t_float)keynum);
@@ -1916,8 +1924,8 @@ void canvas_menuclose(t_canvas *x, t_floatarg fforce)
         }
         else if (sys_perf)
         {
-            sys_vgui("pdtk_canvas_menuclose .x%lx {.x%lx menuclose 1;\n}\n",
-                     canvas_getrootfor(g), g);
+            sys_vgui("pdtk_check .x%lx {Close this window?} {.x%lx menuclose 1;\n} yes\n",
+                     canvas_getrootfor(x), x);
         }
         else pd_free(&x->gl_pd);
     }
