@@ -106,7 +106,7 @@ t_template *template_new(t_symbol *templatesym, int argc, t_atom *argv)
     bad: 
         argc -= 2; argv += 2;
     }
-    if (templatesym->s_name)
+    if (*templatesym->s_name)
     {
         x->t_sym = templatesym;
         pd_bind(&x->t_pdobj, x->t_sym);
@@ -147,7 +147,7 @@ t_float template_getfloat(t_template *x, t_symbol *fieldname, t_word *wp,
 {
     int onset, type;
     t_symbol *arraytype;
-    float val = 0;
+    t_float val = 0;
     if (template_find_field(x, fieldname, &onset, &type, &arraytype))
     {
         if (type == DT_FLOAT)
@@ -484,7 +484,7 @@ void template_notify(t_template *template, t_symbol *s, int argc, t_atom *argv)
 
     /* bash the first of (argv) with a pointer to a scalar, and send on
     to template as a notification message */
-static void template_notifyforscalar(t_template *template, t_glist *owner,
+void template_notifyforscalar(t_template *template, t_glist *owner,
     t_scalar *sc, t_symbol *s, int argc, t_atom *argv)
 {
     t_gpointer gp;
@@ -728,7 +728,7 @@ struct _fielddesc
     float fd_quantum;   /* quantization in value */ 
 };
 
-static void fielddesc_setfloat_const(t_fielddesc *fd, float f)
+static void fielddesc_setfloat_const(t_fielddesc *fd, t_float f)
 {
     fd->fd_type = A_FLOAT;
     fd->fd_var = 0;
@@ -762,14 +762,20 @@ static void fielddesc_setfloat_var(t_fielddesc *fd, t_symbol *s)
     else
     {
         int cpy = s1 - s->s_name, got;
+        double v1, v2, screen1, screen2, quantum;
         if (cpy > MAXPDSTRING-5)
             cpy = MAXPDSTRING-5;
         strncpy(strbuf, s->s_name, cpy);
         strbuf[cpy] = 0;
         fd->fd_un.fd_varsym = gensym(strbuf);
-        got = sscanf(s1, "(%f:%f)(%f:%f)(%f)",
-            &fd->fd_v1, &fd->fd_v2, &fd->fd_screen1, &fd->fd_screen2,
-                &fd->fd_quantum);
+        got = sscanf(s1, "(%lf:%lf)(%lf:%lf)(%lf)",
+            &v1, &v2, &screen1, &screen2,
+                &quantum);
+        fd->fd_v1=v1;
+        fd->fd_v2=v2;
+        fd->fd_screen1=screen1;
+        fd->fd_screen2=screen2;
+        fd->fd_quantum=quantum;
         if (got < 2)
             goto fail;
         if (got == 3 || (got < 4 && strchr(s2, '(')))
@@ -851,9 +857,9 @@ static t_float fielddesc_getfloat(t_fielddesc *f, t_template *template,
 }
 
     /* convert a variable's value to a screen coordinate via its fielddesc */
-t_float fielddesc_cvttocoord(t_fielddesc *f, float val)
+t_float fielddesc_cvttocoord(t_fielddesc *f, t_float val)
 {
-    float coord, pix, extreme, div;
+    t_float coord, pix, extreme, div;
     if (f->fd_v2 == f->fd_v1)
         return (val);
     div = (f->fd_screen2 - f->fd_screen1)/(f->fd_v2 - f->fd_v1);
@@ -877,7 +883,7 @@ t_float fielddesc_getcoord(t_fielddesc *f, t_template *template,
     {
         if (f->fd_var)
         {
-            float val = template_getfloat(template,
+            t_float val = template_getfloat(template,
                 f->fd_un.fd_varsym, wp, loud);
             return (fielddesc_cvttocoord(f, val));
         }
@@ -909,15 +915,15 @@ static t_symbol *fielddesc_getsymbol(t_fielddesc *f, t_template *template,
 }
 
     /* convert from a screen coordinate to a variable value */
-float fielddesc_cvtfromcoord(t_fielddesc *f, float coord)
+t_float fielddesc_cvtfromcoord(t_fielddesc *f, t_float coord)
 {
-    float val;
+    t_float val;
     if (f->fd_screen2 == f->fd_screen1)
         val = coord;
     else
     {
-        float div = (f->fd_v2 - f->fd_v1)/(f->fd_screen2 - f->fd_screen1);
-        float extreme;
+        t_float div = (f->fd_v2 - f->fd_v1)/(f->fd_screen2 - f->fd_screen1);
+        t_float extreme;
         val = f->fd_v1 + (coord - f->fd_screen1) * div;
         if (f->fd_quantum != 0)
             val = ((int)((val/f->fd_quantum) + 0.5)) *  f->fd_quantum;
@@ -932,11 +938,11 @@ float fielddesc_cvtfromcoord(t_fielddesc *f, float coord)
  }
 
 void fielddesc_setcoord(t_fielddesc *f, t_template *template,
-    t_word *wp, float coord, int loud)
+    t_word *wp, t_float coord, int loud)
 {
     if (f->fd_type == A_FLOAT && f->fd_var)
     {
-        float val = fielddesc_cvtfromcoord(f, coord);
+        t_float val = fielddesc_cvtfromcoord(f, coord);
         template_setfloat(template,
                 f->fd_un.fd_varsym, wp, val, loud);
     }
@@ -1040,7 +1046,7 @@ void curve_float(t_curve *x, t_floatarg f)
 /* -------------------- widget behavior for curve ------------ */
 
 static void curve_getrect(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int *xp1, int *yp1, int *xp2, int *yp2)
 {
     t_curve *x = (t_curve *)z;
@@ -1072,21 +1078,21 @@ static void curve_getrect(t_gobj *z, t_glist *glist,
 }
 
 static void curve_displace(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int dx, int dy)
 {
     /* refuse */
 }
 
 static void curve_select(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int state)
 {
     /* fill in later */
 }
 
 static void curve_activate(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int state)
 {
     /* fill in later */
@@ -1122,21 +1128,22 @@ static void numbertocolor(int n, char *s)
 }
 
 static void curve_vis(t_gobj *z, t_glist *glist, 
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int vis)
 {
     t_curve *x = (t_curve *)z;
     int i, n = x->x_npoints;
     t_fielddesc *f = x->x_vec;
     
-    if (!fielddesc_getfloat(&x->x_vis, template, data, 0))
+        /* see comment in plot_vis() */
+    if (vis && !fielddesc_getfloat(&x->x_vis, template, data, 0))
         return;
     if (vis)
     {
         if (n > 1)
         {
             int flags = x->x_flags, closed = (flags & CLOSED);
-            float width = fielddesc_getfloat(&x->x_width, template, data, 1);
+            t_float width = fielddesc_getfloat(&x->x_width, template, data, 1);
             char outline[20], fill[20];
             int pix[200];
             if (n > 100)
@@ -1184,12 +1191,12 @@ static void curve_vis(t_gobj *z, t_glist *glist,
 }
 
 static int curve_motion_field;
-static float curve_motion_xcumulative;
-static float curve_motion_xbase;
-static float curve_motion_xper;
-static float curve_motion_ycumulative;
-static float curve_motion_ybase;
-static float curve_motion_yper;
+static t_float curve_motion_xcumulative;
+static t_float curve_motion_xbase;
+static t_float curve_motion_xper;
+static t_float curve_motion_ycumulative;
+static t_float curve_motion_ybase;
+static t_float curve_motion_yper;
 static t_glist *curve_motion_glist;
 static t_scalar *curve_motion_scalar;
 static t_array *curve_motion_array;
@@ -1236,7 +1243,7 @@ static void curve_motion(void *z, t_floatarg dx, t_floatarg dy)
 
 static int curve_click(t_gobj *z, t_glist *glist, 
     t_word *data, t_template *template, t_scalar *sc, t_array *ap,
-    float basex, float basey,
+    t_float basex, t_float basey,
     int xpix, int ypix, int shift, int alt, int dbl, int doit)
 {
     t_curve *x = (t_curve *)z;
@@ -1269,7 +1276,7 @@ static int curve_click(t_gobj *z, t_glist *glist,
             bestn = i;
         }
     }
-    if (besterror > 10)
+    if (besterror > 6)
         return (0);
     if (doit)
     {
@@ -1437,8 +1444,8 @@ void plot_float(t_plot *x, t_floatarg f)
 static int plot_readownertemplate(t_plot *x,
     t_word *data, t_template *ownertemplate, 
     t_symbol **elemtemplatesymp, t_array **arrayp,
-    float *linewidthp, float *xlocp, float *xincp, float *ylocp, float *stylep,
-    float *visp, float *scalarvisp,
+    t_float *linewidthp, t_float *xlocp, t_float *xincp, t_float *ylocp, t_float *stylep,
+    t_float *visp, t_float *scalarvisp,
     t_fielddesc **xfield, t_fielddesc **yfield, t_fielddesc **wfield)
 {
     int arrayonset, type;
@@ -1537,7 +1544,7 @@ int array_getfields(t_symbol *elemtemplatesym,
 }
 
 static void plot_getrect(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int *xp1, int *yp1, int *xp2, int *yp2)
 {
     t_plot *x = (t_plot *)z;
@@ -1545,11 +1552,11 @@ static void plot_getrect(t_gobj *z, t_glist *glist,
     t_canvas *elemtemplatecanvas;
     t_template *elemtemplate;
     t_symbol *elemtemplatesym;
-    float linewidth, xloc, xinc, yloc, style, xsum, yval, vis, scalarvis;
+    t_float linewidth, xloc, xinc, yloc, style, xsum, yval, vis, scalarvis;
     t_array *array;
     int x1 = 0x7fffffff, y1 = 0x7fffffff, x2 = -0x7fffffff, y2 = -0x7fffffff;
     int i;
-    float xpix, ypix, wpix;
+    t_float xpix, ypix, wpix;
     t_fielddesc *xfielddesc, *yfielddesc, *wfielddesc;
     if (!plot_readownertemplate(x, data, template, 
         &elemtemplatesym, &array, &linewidth, &xloc, &xinc, &yloc, &style,
@@ -1564,7 +1571,7 @@ static void plot_getrect(t_gobj *z, t_glist *glist,
         int incr = (array->a_n <= 2000 ? 1 : array->a_n / 1000);
         for (i = 0, xsum = 0; i < array->a_n; i += incr)
         {
-            float usexloc, useyloc;
+            t_float usexloc, useyloc;
             t_gobj *y;
                 /* get the coords of the point proper */
             array_getcoordinate(glist, (char *)(array->a_vec) + i * elemsize,
@@ -1584,11 +1591,11 @@ static void plot_getrect(t_gobj *z, t_glist *glist,
                     /* check also the drawing instructions for the scalar */ 
                 if (xonset >= 0)
                     usexloc = basex + xloc + fielddesc_cvttocoord(xfielddesc, 
-                        *(float *)(((char *)(array->a_vec) + elemsize * i)
+                        *(t_float *)(((char *)(array->a_vec) + elemsize * i)
                             + xonset));
                 else usexloc = basex + xsum, xsum += xinc;
                 if (yonset >= 0)
-                    yval = *(float *)(((char *)(array->a_vec) + elemsize * i)
+                    yval = *(t_float *)(((char *)(array->a_vec) + elemsize * i)
                         + yonset);
                 else yval = 0;
                 useyloc = basey + yloc + fielddesc_cvttocoord(yfielddesc, yval);
@@ -1621,28 +1628,28 @@ static void plot_getrect(t_gobj *z, t_glist *glist,
 }
 
 static void plot_displace(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int dx, int dy)
 {
         /* not yet */
 }
 
 static void plot_select(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int state)
 {
     /* not yet */
 }
 
 static void plot_activate(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int state)
 {
         /* not yet */
 }
 
 static void plot_vis(t_gobj *z, t_glist *glist, 
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int tovis)
 {
     t_plot *x = (t_plot *)z;
@@ -1650,17 +1657,25 @@ static void plot_vis(t_gobj *z, t_glist *glist,
     t_canvas *elemtemplatecanvas;
     t_template *elemtemplate;
     t_symbol *elemtemplatesym;
-    float linewidth, xloc, xinc, yloc, style, usexloc, xsum, yval, vis,
+    t_float linewidth, xloc, xinc, yloc, style, usexloc, xsum, yval, vis,
         scalarvis;
     t_array *array;
     int nelem;
     char *elem;
     t_fielddesc *xfielddesc, *yfielddesc, *wfielddesc;
-    
+        /* even if the array is "invisible", if its visibility is
+        set by an instance variable you have to explicitly erase it,
+        because the flag could earlier have been on when we were getting
+        drawn.  Rather than look to try to find out whether we're
+        visible we just do the erasure.  At the TK level this should
+        cause no action because the tag matches nobody.  LATER we
+        might want to optimize this somehow.  Ditto the "vis()" routines
+        for other drawing instructions. */
+        
     if (plot_readownertemplate(x, data, template, 
         &elemtemplatesym, &array, &linewidth, &xloc, &xinc, &yloc, &style,
         &vis, &scalarvis, &xfielddesc, &yfielddesc, &wfielddesc) ||
-            ((vis == 0) && tovis) /* FIXME - why is 'tovis' flag necessary? */
+            ((vis == 0) && tovis) /* see above for 'tovis' */
             || array_getfields(elemtemplatesym, &elemtemplatecanvas,
                 &elemtemplate, &elemsize, xfielddesc, yfielddesc, wfielddesc,
                 &xonset, &yonset, &wonset))
@@ -1672,17 +1687,17 @@ static void plot_vis(t_gobj *z, t_glist *glist,
     {
         if (style == PLOTSTYLE_POINTS)
         {
-            float minyval = 1e20, maxyval = -1e20;
+            t_float minyval = 1e20, maxyval = -1e20;
             int ndrawn = 0;
             for (xsum = basex + xloc, i = 0; i < nelem; i++)
             {
-                float yval, xpix, ypix, nextxloc;
+                t_float yval, xpix, ypix, nextxloc;
                 int ixpix, inextx;
 
                 if (xonset >= 0)
                 {
                     usexloc = basex + xloc +
-                        *(float *)((elem + elemsize * i) + xonset);
+                        *(t_float *)((elem + elemsize * i) + xonset);
                     ixpix = glist_xtopixels(glist, 
                         fielddesc_cvttocoord(xfielddesc, usexloc));
                     inextx = ixpix + 2;
@@ -1698,7 +1713,7 @@ static void plot_vis(t_gobj *z, t_glist *glist,
                 }
 
                 if (yonset >= 0)
-                    yval = yloc + *(float *)((elem + elemsize * i) + yonset);
+                    yval = yloc + *(t_float *)((elem + elemsize * i) + yonset);
                 else yval = 0;
                 if (yval > maxyval)
                     maxyval = yval;
@@ -1706,8 +1721,8 @@ static void plot_vis(t_gobj *z, t_glist *glist,
                     minyval = yval;
                 if (i == nelem-1 || inextx != ixpix)
                 {
-                    sys_vgui(
-".x%lx.c create rectangle %d %d %d %d -fill black -width 0  -tags plot%lx\n",
+                    sys_vgui(".x%lx.c create rectangle %d %d %d %d \
+-fill black -width 0  -tags [list plot%lx array]\n",
                         glist_getcanvas(glist),
                         ixpix, (int)glist_ytopixels(glist, 
                             basey + fielddesc_cvttocoord(yfielddesc, minyval)),
@@ -1725,7 +1740,7 @@ static void plot_vis(t_gobj *z, t_glist *glist,
         {
             char outline[20];
             int lastpixel = -1, ndrawn = 0;
-            float yval = 0, wval = 0, xpix;
+            t_float yval = 0, wval = 0, xpix;
             int ixpix = 0;
                 /* draw the trace */
             numbertocolor(fielddesc_getfloat(&x->x_outlinecolor, template,
@@ -1740,13 +1755,13 @@ static void plot_vis(t_gobj *z, t_glist *glist,
                 for (i = 0, xsum = xloc; i < nelem; i++)
                 {
                     if (xonset >= 0)
-                        usexloc = xloc + *(float *)((elem + elemsize * i)
+                        usexloc = xloc + *(t_float *)((elem + elemsize * i)
                             + xonset);
                     else usexloc = xsum, xsum += xinc;
                     if (yonset >= 0)
-                        yval = *(float *)((elem + elemsize * i) + yonset);
+                        yval = *(t_float *)((elem + elemsize * i) + yonset);
                     else yval = 0;
-                    wval = *(float *)((elem + elemsize * i) + wonset);
+                    wval = *(t_float *)((elem + elemsize * i) + wonset);
                     xpix = glist_xtopixels(glist,
                         basex + fielddesc_cvttocoord(xfielddesc, usexloc));
                     ixpix = xpix + 0.5;
@@ -1765,15 +1780,15 @@ static void plot_vis(t_gobj *z, t_glist *glist,
                 lastpixel = -1;
                 for (i = nelem-1; i >= 0; i--)
                 {
-                    float usexloc;
+                    t_float usexloc;
                     if (xonset >= 0)
-                        usexloc = xloc + *(float *)((elem + elemsize * i)
+                        usexloc = xloc + *(t_float *)((elem + elemsize * i)
                             + xonset);
                     else xsum -= xinc, usexloc = xsum;
                     if (yonset >= 0)
-                        yval = *(float *)((elem + elemsize * i) + yonset);
+                        yval = *(t_float *)((elem + elemsize * i) + yonset);
                     else yval = 0;
-                    wval = *(float *)((elem + elemsize * i) + wonset);
+                    wval = *(t_float *)((elem + elemsize * i) + wonset);
                     xpix = glist_xtopixels(glist,
                         basex + fielddesc_cvttocoord(xfielddesc, usexloc));
                     ixpix = xpix + 0.5;
@@ -1806,7 +1821,7 @@ static void plot_vis(t_gobj *z, t_glist *glist,
                     outline, outline);
                 if (style == PLOTSTYLE_BEZ) sys_vgui("-smooth 1\\\n");
 
-                sys_vgui("-tags plot%lx\n", data);
+                sys_vgui("-tags [list plot%lx array]\n", data);
             }
             else if (linewidth > 0)
             {
@@ -1817,13 +1832,13 @@ static void plot_vis(t_gobj *z, t_glist *glist,
 
                 for (xsum = xloc, i = 0; i < nelem; i++)
                 {
-                    float usexloc;
+                    t_float usexloc;
                     if (xonset >= 0)
-                        usexloc = xloc + *(float *)((elem + elemsize * i) +
+                        usexloc = xloc + *(t_float *)((elem + elemsize * i) +
                             xonset);
                     else usexloc = xsum, xsum += xinc;
                     if (yonset >= 0)
-                        yval = *(float *)((elem + elemsize * i) + yonset);
+                        yval = *(t_float *)((elem + elemsize * i) + yonset);
                     else yval = 0;
                     xpix = glist_xtopixels(glist,
                         basex + fielddesc_cvttocoord(xfielddesc, usexloc));
@@ -1849,7 +1864,7 @@ static void plot_vis(t_gobj *z, t_glist *glist,
                 sys_vgui("-fill %s\\\n", outline);
                 if (style == PLOTSTYLE_BEZ) sys_vgui("-smooth 1\\\n");
 
-                sys_vgui("-tags plot%lx\n", data);
+                sys_vgui("-tags [list plot%lx array]\n", data);
             }
         }
             /* We're done with the outline; now draw all the points.
@@ -1859,14 +1874,14 @@ static void plot_vis(t_gobj *z, t_glist *glist,
         {
             for (xsum = xloc, i = 0; i < nelem; i++)
             {
-                float usexloc, useyloc;
+                t_float usexloc, useyloc;
                 t_gobj *y;
                 if (xonset >= 0)
                     usexloc = basex + xloc +
-                        *(float *)((elem + elemsize * i) + xonset);
+                        *(t_float *)((elem + elemsize * i) + xonset);
                 else usexloc = basex + xsum, xsum += xinc;
                 if (yonset >= 0)
-                    yval = *(float *)((elem + elemsize * i) + yonset);
+                    yval = *(t_float *)((elem + elemsize * i) + yonset);
                 else yval = 0;
                 useyloc = basey + yloc +
                     fielddesc_cvttocoord(yfielddesc, yval);
@@ -1908,12 +1923,12 @@ static void plot_vis(t_gobj *z, t_glist *glist,
 
 static int plot_click(t_gobj *z, t_glist *glist, 
     t_word *data, t_template *template, t_scalar *sc, t_array *ap,
-    float basex, float basey,
+    t_float basex, t_float basey,
     int xpix, int ypix, int shift, int alt, int dbl, int doit)
 {
     t_plot *x = (t_plot *)z;
     t_symbol *elemtemplatesym;
-    float linewidth, xloc, xinc, yloc, style, vis, scalarvis;
+    t_float linewidth, xloc, xinc, yloc, style, vis, scalarvis;
     t_array *array;
     t_fielddesc *xfielddesc, *yfielddesc, *wfielddesc;
 
@@ -2049,7 +2064,7 @@ static void drawnumber_sprintf(t_drawnumber *x, char *buf, t_atom *ap)
 }
 
 static void drawnumber_getrect(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int *xp1, int *yp1, int *xp2, int *yp2)
 {
     t_drawnumber *x = (t_drawnumber *)z;
@@ -2081,14 +2096,14 @@ static void drawnumber_getrect(t_gobj *z, t_glist *glist,
 }
 
 static void drawnumber_displace(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int dx, int dy)
 {
     /* refuse */
 }
 
 static void drawnumber_select(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int state)
 {
     post("drawnumber_select %d", state);
@@ -2096,19 +2111,20 @@ static void drawnumber_select(t_gobj *z, t_glist *glist,
 }
 
 static void drawnumber_activate(t_gobj *z, t_glist *glist,
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int state)
 {
     post("drawnumber_activate %d", state);
 }
 
 static void drawnumber_vis(t_gobj *z, t_glist *glist, 
-    t_word *data, t_template *template, float basex, float basey,
+    t_word *data, t_template *template, t_float basex, t_float basey,
     int vis)
 {
     t_drawnumber *x = (t_drawnumber *)z;
     
-    if (!fielddesc_getfloat(&x->x_vis, template, data, 0))
+        /* see comment in plot_vis() */
+    if (vis && !fielddesc_getfloat(&x->x_vis, template, data, 0))
         return;
     if (vis)
     {
@@ -2126,14 +2142,14 @@ static void drawnumber_vis(t_gobj *z, t_glist *glist,
         drawnumber_sprintf(x, buf, &at);
         sys_vgui(".x%lx.c create text %d %d -anchor nw -fill %s -text {%s}",
                 glist_getcanvas(glist), xloc, yloc, colorstring, buf);
-        sys_vgui(" -font -*-courier-bold--normal--%d-*",
-            sys_hostfontsize(glist_getfont(glist)));
-        sys_vgui(" -tags drawnumber%lx\n", data);
+        sys_vgui(" -font {{%s} -%d %s}", sys_font,
+                 sys_hostfontsize(glist_getfont(glist)), sys_fontweight);
+        sys_vgui(" -tags [list drawnumber%lx label]\n", data);
     }
     else sys_vgui(".x%lx.c delete drawnumber%lx\n", glist_getcanvas(glist), data);
 }
 
-static float drawnumber_motion_ycumulative;
+static t_float drawnumber_motion_ycumulative;
 static t_glist *drawnumber_motion_glist;
 static t_scalar *drawnumber_motion_scalar;
 static t_array *drawnumber_motion_array;
@@ -2215,7 +2231,7 @@ static void drawnumber_key(void *z, t_floatarg fkey)
     else
     {
             /* key entry for a numeric field.  This is just a stopgap. */
-        float newf;
+        double newf;
         if (drawnumber_motion_firstkey)
             sbuf[0] = 0;
         else sprintf(sbuf, "%g", template_getfloat(drawnumber_motion_template,
@@ -2231,10 +2247,10 @@ static void drawnumber_key(void *z, t_floatarg fkey)
             sbuf[strlen(sbuf)+1] = 0;
             sbuf[strlen(sbuf)] = key;
         }
-        if (sscanf(sbuf, "%g", &newf) < 1)
+        if (sscanf(sbuf, "%lg", &newf) < 1)
             newf = 0;
         template_setfloat(drawnumber_motion_template,
-            f->fd_un.fd_varsym, drawnumber_motion_wp, newf, 1);
+            f->fd_un.fd_varsym, drawnumber_motion_wp, (t_float)newf, 1);
         if (drawnumber_motion_scalar)
             template_notifyforscalar(drawnumber_motion_template,
                 drawnumber_motion_glist, drawnumber_motion_scalar,
@@ -2248,7 +2264,7 @@ static void drawnumber_key(void *z, t_floatarg fkey)
 
 static int drawnumber_click(t_gobj *z, t_glist *glist, 
     t_word *data, t_template *template, t_scalar *sc, t_array *ap,
-    float basex, float basey,
+    t_float basex, t_float basey,
     int xpix, int ypix, int shift, int alt, int dbl, int doit)
 {
     t_drawnumber *x = (t_drawnumber *)z;
