@@ -15,7 +15,7 @@ union inletunion
     t_gpointer *iu_pointerslot;
     t_float *iu_floatslot;
     t_symbol **iu_symslot;
-    t_sample iu_floatsignalvalue;
+    t_float iu_floatsignalvalue;
 };
 
 struct _inlet
@@ -75,12 +75,16 @@ static void inlet_wrong(t_inlet *x, t_symbol *s)
         x->i_symfrom->s_name, s->s_name);
 }
 
+static void inlet_list(t_inlet *x, t_symbol *s, int argc, t_atom *argv);
+
     /* LATER figure out how to make these efficient: */
 static void inlet_bang(t_inlet *x)
 {
     if (x->i_symfrom == &s_bang) 
         pd_vmess(x->i_dest, x->i_symto, "");
     else if (!x->i_symfrom) pd_bang(x->i_dest);
+    else if (x->i_symfrom == &s_list)
+        inlet_list(x, &s_bang, 0, 0);
     else inlet_wrong(x, &s_bang);
 }
 
@@ -89,6 +93,12 @@ static void inlet_pointer(t_inlet *x, t_gpointer *gp)
     if (x->i_symfrom == &s_pointer) 
         pd_vmess(x->i_dest, x->i_symto, "p", gp);
     else if (!x->i_symfrom) pd_pointer(x->i_dest, gp);
+    else if (x->i_symfrom == &s_list)
+    {
+        t_atom a;
+        SETPOINTER(&a, gp);
+        inlet_list(x, &s_pointer, 1, &a);
+    }
     else inlet_wrong(x, &s_pointer);
 }
 
@@ -100,6 +110,12 @@ static void inlet_float(t_inlet *x, t_float f)
         x->i_un.iu_floatsignalvalue = f;
     else if (!x->i_symfrom)
         pd_float(x->i_dest, f);
+    else if (x->i_symfrom == &s_list)
+    {
+        t_atom a;
+        SETFLOAT(&a, f);
+        inlet_list(x, &s_float, 1, &a);
+    }
     else inlet_wrong(x, &s_float);
 }
 
@@ -108,6 +124,12 @@ static void inlet_symbol(t_inlet *x, t_symbol *s)
     if (x->i_symfrom == &s_symbol) 
         pd_vmess(x->i_dest, x->i_symto, "s", s);
     else if (!x->i_symfrom) pd_symbol(x->i_dest, s);
+    else if (x->i_symfrom == &s_list)
+    {
+        t_atom a;
+        SETSYMBOL(&a, s);
+        inlet_list(x, &s_symbol, 1, &a);
+    }
     else inlet_wrong(x, &s_symbol);
 }
 
@@ -118,6 +140,12 @@ static void inlet_list(t_inlet *x, t_symbol *s, int argc, t_atom *argv)
         || x->i_symfrom == &s_symbol || x->i_symfrom == &s_pointer)
             typedmess(x->i_dest, x->i_symto, argc, argv);
     else if (!x->i_symfrom) pd_list(x->i_dest, s, argc, argv);
+    else if (!argc)
+      inlet_bang(x);
+    else if (argc==1 && argv->a_type == A_FLOAT)
+      inlet_float(x, atom_getfloat(argv));
+    else if (argc==1 && argv->a_type == A_SYMBOL)
+      inlet_symbol(x, atom_getsymbol(argv));
     else inlet_wrong(x, &s_list);
 }
 
@@ -250,14 +278,17 @@ void obj_init(void)
     pointerinlet_class = class_new(gensym("inlet"), 0, 0,
         sizeof(t_inlet), CLASS_PD, 0);
     class_addpointer(pointerinlet_class, pointerinlet_pointer);
-
+    class_addanything(pointerinlet_class, inlet_wrong);
+    
     floatinlet_class = class_new(gensym("inlet"), 0, 0,
         sizeof(t_inlet), CLASS_PD, 0);
     class_addfloat(floatinlet_class, (t_method)floatinlet_float);
+    class_addanything(floatinlet_class, inlet_wrong);
 
     symbolinlet_class = class_new(gensym("inlet"), 0, 0,
         sizeof(t_inlet), CLASS_PD, 0);
     class_addsymbol(symbolinlet_class, symbolinlet_symbol);
+    class_addanything(symbolinlet_class, inlet_wrong);
 
 }
 
@@ -657,7 +688,7 @@ int obj_issignaloutlet(t_object *x, int m)
     return (o2 && (o2->o_sym == &s_signal));
 }
 
-t_sample *obj_findsignalscalar(t_object *x, int m)
+t_float *obj_findsignalscalar(t_object *x, int m)
 {
     int n = 0;
     t_inlet *i;
@@ -665,7 +696,7 @@ t_sample *obj_findsignalscalar(t_object *x, int m)
     {
         if (!m--)
             return (x->ob_pd->c_floatsignalin > 0 ?
-                (t_sample *)(((char *)x) + x->ob_pd->c_floatsignalin) : 0);
+                (t_float *)(((char *)x) + x->ob_pd->c_floatsignalin) : 0);
         n++;
     }
     for (i = x->ob_inlet; i; i = i->i_next, m--)
@@ -684,6 +715,8 @@ int inlet_getsignalindex(t_inlet *x)
 {
     int n = 0;
     t_inlet *i;
+    if (x->i_symfrom != &s_signal)
+        bug("inlet_getsignalindex");
     for (i = x->i_owner->ob_inlet, n = 0; i && i != x; i = i->i_next)
         if (i->i_symfrom == &s_signal) n++;
     return (n);
