@@ -694,13 +694,13 @@ idle:
 
 /* ------------------- public routines -------------------------- */
 
-void mmio_open_audio(int naudioindev, int *audioindev,
+int mmio_open_audio(int naudioindev, int *audioindev,
     int nchindev, int *chindev, int naudiooutdev, int *audiooutdev,
-    int nchoutdev, int *choutdev, int rate)
+    int nchoutdev, int *choutdev, int rate, int blocksize)
 {
     int nbuf;
 
-    nt_realdacblksize = (sys_blocksize ? sys_blocksize : DEFREALDACBLKSIZE);
+    nt_realdacblksize = (blocksize ? blocksize : DEFREALDACBLKSIZE);
     nbuf = sys_advance_samples/nt_realdacblksize;
     if (nbuf >= MAXBUFFER)
     {
@@ -709,7 +709,7 @@ void mmio_open_audio(int naudioindev, int *audioindev,
         nbuf = MAXBUFFER;
     }
     else if (nbuf < 4) nbuf = 4;
-    fprintf(stderr, "%d audio buffers\n", nbuf);
+    /* fprintf(stderr, "%d audio buffers\n", nbuf); */
     nt_naudiobuffer = nbuf;
     if (nt_adcjitterbufsallowed > nbuf - 2)
         nt_adcjitterbufsallowed = nbuf - 2;
@@ -724,7 +724,7 @@ void mmio_open_audio(int naudioindev, int *audioindev,
         (nt_nwaveout > 1 ? WAVE_MAPPER : -1) : audiooutdev[0]);
     if (naudiooutdev > 1 || naudioindev > 1)
  post("separate audio device choice not supported; using sequential devices.");
-    mmio_do_open_audio();
+    return (mmio_do_open_audio());
 }
 
 
