@@ -16,7 +16,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
-#ifdef UNISTD
+#ifdef HAVE_UNISTD_H
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -24,16 +24,19 @@
 #include <fcntl.h>
 #include <unistd.h>
 #endif
-#ifdef MSW
+#ifdef _WIN32
 #include <windows.h>
 #include <tchar.h>
 #endif
+#ifdef _MSC_VER  /* This is only for Microsoft's compiler, not cygwin, e.g. */
+#define snprintf sprintf_s
+#endif
 
 int sys_defeatrt;
 t_symbol *sys_flags = &s_;
 void sys_doflags( void);
 
-#ifdef UNIX
+#if defined(__linux__) || defined(__CYGWIN__) || defined(__FreeBSD_kernel__) || defined(__GNU__) || defined(ANDROID)
 
 static char *sys_prefbuf;
 static int sys_prefbufsize;
@@ -42,10 +45,20 @@ static void sys_initloadpreferences( void)
 {
     char filenamebuf[MAXPDSTRING], *homedir = getenv("HOME");
     int fd, length;
+    char user_prefs_file[MAXPDSTRING]; /* user prefs file */
+        /* default prefs embedded in the package */
+    char default_prefs_file[MAXPDSTRING];
+    struct stat statbuf;
 
-    if (!homedir)
-        return;
-    snprintf(filenamebuf, MAXPDSTRING, "%s/.pdsettings", homedir);
+    snprintf(default_prefs_file, MAXPDSTRING, "%s/default.pdsettings", 
+        sys_libdir->s_name);
+    if (homedir)
+        snprintf(user_prefs_file, MAXPDSTRING, "%s/.pdsettings", homedir);
+    if (stat(user_prefs_file, &statbuf) == 0) 
+        strncpy(filenamebuf, user_prefs_file, MAXPDSTRING);
+    else if (stat(default_prefs_file, &statbuf) == 0)
+        strncpy(filenamebuf, default_prefs_file, MAXPDSTRING);
+    else return;
     filenamebuf[MAXPDSTRING-1] = 0;
     if ((fd = open(filenamebuf, 0)) < 0)
     {
@@ -146,9 +159,9 @@ static void sys_donesavepreferences( void)
     }
 }
 
-#endif /* UNIX */
+#endif /* __linux__ || __CYGWIN__ || __FreeBSD_kernel__ || __GNU__ */
 
-#ifdef MSW
+#ifdef _WIN32
 
 static void sys_initloadpreferences( void)
 {
@@ -190,12 +203,12 @@ static void sys_putpreference(const char *key, const char *value)
         NULL, &hkey, NULL);
     if (err != ERROR_SUCCESS)
     {
-        post("unable to create registry entry: %s\n", key);
+        error("unable to create registry entry: %s\n", key);
         return;
     }
-    err = RegSetValueEx(hkey, key, 0, REG_SZ, value, strlen(value)+1);
+    err = RegSetValueEx(hkey, key, 0, REG_EXPAND_SZ, value, strlen(value)+1);
     if (err != ERROR_SUCCESS)
-        post("unable to set registry entry: %s\n", key);
+        error("unable to set registry entry: %s\n", key);
     RegCloseKey(hkey);
 }
 
@@ -203,7 +216,7 @@ static void sys_donesavepreferences( void)
 {
 }
 
-#endif /* MSW */
+#endif /* _WIN32 */
 
 #ifdef __APPLE__
 
@@ -215,7 +228,21 @@ static int sys_getpreference(const char *key, char *value, int size)
 {
     char cmdbuf[256];
     int nread = 0, nleft = size;
-    snprintf(cmdbuf, 256, "defaults read org.puredata.pd %s 2> /dev/null\n", key);
+    char embedded_prefs[MAXPDSTRING];
+    char user_prefs[MAXPDSTRING];
+    char *homedir = getenv("HOME");
+    struct stat statbuf;
+   /* the 'defaults' command expects the filename without .plist at the
+        end */
+    snprintf(embedded_prefs, MAXPDSTRING, "%s/../org.puredata.pd",
+        sys_libdir->s_name);
+    snprintf(user_prefs, MAXPDSTRING,
+        "%s/Library/Preferences/org.puredata.pd.plist", homedir);
+    if (stat(user_prefs, &statbuf) == 0)
+        snprintf(cmdbuf, 256, "defaults read org.puredata.pd %s 2> /dev/null\n",
+            key);
+    else snprintf(cmdbuf, 256, "defaults read %s %s 2> /dev/null\n",
+            embedded_prefs, key);
     FILE *fp = popen(cmdbuf, "r");
     while (nread < size)
     {
@@ -264,7 +291,8 @@ void sys_loadpreferences( void)
     int naudiooutdev, audiooutdev[MAXAUDIOOUTDEV], choutdev[MAXAUDIOOUTDEV];
     int nmidiindev, midiindev[MAXMIDIINDEV];
     int nmidioutdev, midioutdev[MAXMIDIOUTDEV];
-    int i, rate = 0, advance = 0, api, nolib, maxi;
+    int i, rate = 0, advance = -1, callback = 0, blocksize = 0,
+        api, nolib, maxi;
     char prefbuf[MAXPDSTRING], keybuf[80];
 
     sys_initloadpreferences();
@@ -272,8 +300,9 @@ void sys_loadpreferences( void)
     if (sys_getpreference("audioapi", prefbuf, MAXPDSTRING)
         && sscanf(prefbuf, "%d", &api) > 0)
             sys_set_audio_api(api);
+            /* JMZ/MB: brackets for initializing */
     if (sys_getpreference("noaudioin", prefbuf, MAXPDSTRING) &&
-        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True"))) /* JMZ/MB: brackets for initializing */
+        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True")))
             naudioindev = 0;
     else
     {
@@ -290,8 +319,9 @@ void sys_loadpreferences( void)
         if (naudioindev == 0)
             naudioindev = -1;
     }
+        /* JMZ/MB: brackets for initializing */
     if (sys_getpreference("noaudioout", prefbuf, MAXPDSTRING) &&
-        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True"))) /* JMZ/MB: brackets for initializing */
+        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True")))
             naudiooutdev = 0;
     else
     {
@@ -311,12 +341,18 @@ void sys_loadpreferences( void)
         sscanf(prefbuf, "%d", &rate);
     if (sys_getpreference("audiobuf", prefbuf, MAXPDSTRING))
         sscanf(prefbuf, "%d", &advance);
-    sys_open_audio(naudioindev, audioindev, naudioindev, chindev,
-        naudiooutdev, audiooutdev, naudiooutdev, choutdev, rate, advance, 0);
+    if (sys_getpreference("callback", prefbuf, MAXPDSTRING))
+        sscanf(prefbuf, "%d", &callback);
+    if (sys_getpreference("blocksize", prefbuf, MAXPDSTRING))
+        sscanf(prefbuf, "%d", &blocksize);
+    sys_set_audio_settings(naudioindev, audioindev, naudioindev, chindev,
+        naudiooutdev, audiooutdev, naudiooutdev, choutdev, rate, advance,
+        callback, blocksize);
         
         /* load MIDI preferences */
+        /* JMZ/MB: brackets for initializing */
     if (sys_getpreference("nomidiin", prefbuf, MAXPDSTRING) &&
-        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True"))) /* JMZ/MB: brackets for initializing */
+        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True")))
             nmidiindev = 0;
     else for (i = 0, nmidiindev = 0; i < MAXMIDIINDEV; i++)
     {
@@ -327,8 +363,9 @@ void sys_loadpreferences( void)
             break;
         nmidiindev++;
     }
+        /* JMZ/MB: brackets for initializing */
     if (sys_getpreference("nomidiout", prefbuf, MAXPDSTRING) &&
-        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True"))) /* JMZ/MB: brackets for initializing */
+        (!strcmp(prefbuf, ".") || !strcmp(prefbuf, "True")))
             nmidioutdev = 0;
     else for (i = 0, nmidioutdev = 0; i < MAXMIDIOUTDEV; i++)
     {
@@ -380,10 +417,10 @@ void sys_loadpreferences( void)
     if (sys_defeatrt)
         sys_hipriority = 0;
     else
-#ifdef UNIX
-        sys_hipriority = !geteuid();
+#if defined(__linux__) || defined(__CYGWIN__)
+        sys_hipriority = 1;
 #else
-#ifdef MSW
+#if defined(_WIN32) || defined(ANDROID)
         sys_hipriority = 0;
 #else
         sys_hipriority = 1;
@@ -395,7 +432,7 @@ void glob_savepreferences(t_pd *dummy)
 {
     int naudioindev, audioindev[MAXAUDIOINDEV], chindev[MAXAUDIOINDEV];
     int naudiooutdev, audiooutdev[MAXAUDIOOUTDEV], choutdev[MAXAUDIOOUTDEV];
-    int i, rate, advance;
+    int i, rate, advance, callback, blocksize;
     char buf1[MAXPDSTRING], buf2[MAXPDSTRING];
     int nmidiindev, midiindev[MAXMIDIINDEV];
     int nmidioutdev, midioutdev[MAXMIDIOUTDEV];
@@ -408,7 +445,8 @@ void glob_savepreferences(t_pd *dummy)
     sys_putpreference("audioapi", buf1);
 
     sys_get_audio_params(&naudioindev, audioindev, chindev,
-        &naudiooutdev, audiooutdev, choutdev, &rate, &advance);
+        &naudiooutdev, audiooutdev, choutdev, &rate, &advance, &callback,
+            &blocksize);
 
     sys_putpreference("noaudioin", (naudioindev <= 0 ? "True" : "False"));
     for (i = 0; i < naudioindev; i++)
@@ -431,6 +469,12 @@ void glob_savepreferences(t_pd *dummy)
     sprintf(buf1, "%d", rate);
     sys_putpreference("rate", buf1);
 
+    sprintf(buf1, "%d", callback);
+    sys_putpreference("callback", buf1);
+
+    sprintf(buf1, "%d", blocksize);
+    sys_putpreference("blocksize", buf1);
+
         /* MIDI settings */
     sys_get_midi_params(&nmidiindev, midiindev, &nmidioutdev, midioutdev);
     sys_putpreference("nomidiin", (nmidiindev <= 0 ? "True" : "False"));
