@@ -7,14 +7,14 @@
 #include "m_pd.h"
 #include "s_stuff.h"
 #include "m_imp.h"
-#ifdef UNISTD
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #include <sys/time.h>
 #ifdef HAVE_BSTRING_H
 #include <bstring.h>
 #endif
 #endif
-#ifdef MSW
+#ifdef _WIN32
 #include <winsock.h>
 #include <sys/types.h>
 #include <sys/timeb.h> 
@@ -669,12 +669,12 @@ void glob_midi_properties(t_pd *dummy, t_floatarg flongform)
 
     sys_gui("global midi_indevlist; set midi_indevlist {none}\n");
     for (i = 0; i < nindevs; i++)
-        sys_vgui("lappend midi_indevlist \"%s\"\n",
+        sys_vgui("lappend midi_indevlist {%s}\n",
             indevlist + i * DEVDESCSIZE);
 
     sys_gui("global midi_outdevlist; set midi_outdevlist {none}\n");
     for (i = 0; i < noutdevs; i++)
-        sys_vgui("lappend midi_outdevlist \"%s\"\n",
+        sys_vgui("lappend midi_outdevlist {%s}\n",
             outdevlist + i * DEVDESCSIZE);
 
     sys_get_midi_params(&nindev, midiindev, &noutdev, midioutdev);
@@ -762,3 +762,17 @@ void glob_midi_dialog(t_pd *dummy, t_symbol *s, int argc, t_atom *argv)
       }
 
 }
+
+void sys_get_midi_devs(char *indevlist, int *nindevs,
+                       char *outdevlist, int *noutdevs, 
+                       int maxndevs, int devdescsize)
+{
+
+#ifdef USEAPI_ALSA
+  if (sys_midiapi == API_ALSA)
+    midi_alsa_getdevs(indevlist, nindevs, outdevlist, noutdevs, 
+                      maxndevs, devdescsize);
+  else
+#endif /* ALSA */
+  midi_getdevs(indevlist, nindevs, outdevlist, noutdevs, maxndevs, devdescsize);
+}
