@@ -8,7 +8,7 @@ away before the panel does... */
 #include "m_pd.h"
 #include <stdio.h>
 #include <string.h>
-#ifdef UNISTD
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
@@ -46,6 +46,9 @@ void gfxstub_new(t_pd *owner, void *key, const char *cmd)
 {
     char buf[4*MAXPDSTRING];
     char namebuf[80];
+    char sprintfbuf[MAXPDSTRING];
+    char *afterpercent;
+    t_int afterpercentlen;
     t_gfxstub *x;
     t_symbol *s;
         /* if any exists with matching key, burn it. */
@@ -55,7 +58,7 @@ void gfxstub_new(t_pd *owner, void *key, const char *cmd)
     if (strlen(cmd) + 50 > 4*MAXPDSTRING)
     {
         bug("audio dialog too long");
-        bug("%x", cmd);
+        bug("%s", cmd);
         return;
     }
     x = (t_gfxstub *)pd_new(gfxstub_class);
@@ -68,7 +71,13 @@ void gfxstub_new(t_pd *owner, void *key, const char *cmd)
     x->x_key = key;
     x->x_next = gfxstub_list;
     gfxstub_list = x;
-    sprintf(buf, cmd, s->s_name);
+    /* only replace first %s so sprintf() doesn't crash */
+    afterpercent = strchr(cmd, '%') + 2;
+    afterpercentlen = afterpercent - cmd;
+    strncpy(sprintfbuf, cmd, afterpercentlen);
+    sprintfbuf[afterpercentlen] = '\0';
+    sprintf(buf, sprintfbuf, s->s_name);
+    strncat(buf, afterpercent, (4*MAXPDSTRING) - afterpercentlen);
     sys_gui(buf);
 }
 
@@ -158,8 +167,7 @@ static void gfxstub_free(t_gfxstub *x)
 
 static void gfxstub_setup(void)
 {
-    gfxstub_class = class_new(gensym("gfxstub"), (t_newmethod)gfxstub_new,
-        (t_method)gfxstub_free,
+    gfxstub_class = class_new(gensym("gfxstub"), 0, (t_method)gfxstub_free,
         sizeof(t_gfxstub), CLASS_PD, 0);
     class_addanything(gfxstub_class, gfxstub_anything);
     class_addmethod(gfxstub_class, (t_method)gfxstub_signoff,
@@ -233,6 +241,7 @@ static t_class *savepanel_class;
 typedef struct _savepanel
 {
     t_object x_obj;
+    t_canvas *x_canvas;
     t_symbol *x_s;
 } t_savepanel;
 
@@ -242,6 +251,7 @@ static void *savepanel_new( void)
     t_savepanel *x = (t_savepanel *)pd_new(savepanel_class);
     sprintf(buf, "d%lx", (t_int)x);
     x->x_s = gensym(buf);
+    x->x_canvas = canvas_getcurrent();
     pd_bind(&x->x_obj.ob_pd, x->x_s);
     outlet_new(&x->x_obj, &s_symbol);
     return (x);
