@@ -612,7 +612,7 @@ static void *midirealtimein_new( void)
     x->x_outlet1 = outlet_new(&x->x_obj, &s_float);
     x->x_outlet2 = outlet_new(&x->x_obj, &s_float);
     pd_bind(&x->x_obj.ob_pd, midirealtimein_sym);
-#ifndef MSW
+#ifndef _WIN32
     pd_error(x, "midirealtimein: works under MSW only");
 #endif
     return (x);
